==> open-xchange-core_7.6.2.orig.tar.bz2: open-xchange-core-7.6.2/com.openexchange.version/src/com/openexchange/version/Version.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.version;

import com.openexchange.version.internal.Numbers;

/**
 * Stores the version of the backend
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public class Version {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Version.class);

    public static final String CODENAME = "Hyperion";
    public static final String NAME = "Open-Xchange";

    public static final Version SINGLETON = new Version();

    private Numbers numbers = null;
    private String buildDate = null;
    private String versionString = null;

    public String getBuildDate() {
        if (null == buildDate) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return buildDate;
    }

    public String getVersionString() {
        synchronized (this) {
            if (null == versionString) {
                if (null == numbers) {
                    IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
                    LOG.error("", e);
                    throw e;
                }
                versionString = numbers.getVersion() + "-Rev" + numbers.getBuildNumber();
            }
        }
        return versionString;
    }

    public int getMajor() {
        if (null == numbers) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return numbers.getMajor();
    }

    public int getMinor() {
        if (null == numbers) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return numbers.getMinor();
    }

    public int getPatch() {
        if (null == numbers) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return numbers.getPatch();
    }

    private Version() {
        super();
    }

    public static final Version getInstance() {
        return SINGLETON;
    }

    public void setNumbers(Numbers numbers) {
        this.numbers = numbers;
    }

    public void setBuildDate(String buildDate) {
        this.buildDate = buildDate;
    }
}

==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.version/src/com/openexchange/version/Version.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.version;

import com.openexchange.version.internal.Numbers;

/**
 * Stores the version of the backend
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public class Version {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Version.class);

    public static final String CODENAME = "Hyperion";
    public static final String NAME = "Open-Xchange";

    public static final Version SINGLETON = new Version();

    private Numbers numbers = null;
    private String buildDate = null;
    private String versionString = null;

    public String getBuildDate() {
        if (null == buildDate) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return buildDate;
    }

    public String getVersionString() {
        synchronized (this) {
            if (null == versionString) {
                if (null == numbers) {
                    IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
                    LOG.error("", e);
                    throw e;
                }
                versionString = numbers.getVersion() + "-Rev" + numbers.getBuildNumber();
            }
        }
        return versionString;
    }

    /**
     * Optionally gets the version string.
     *
     * @return The version string, or <code>null</code> if it is not yet initialized
     */
    public String optVersionString() {
        return versionString;
    }

    public int getMajor() {
        if (null == numbers) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return numbers.getMajor();
    }

    public int getMinor() {
        if (null == numbers) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return numbers.getMinor();
    }

    public int getPatch() {
        if (null == numbers) {
            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
            LOG.error("", e);
            throw e;
        }
        return numbers.getPatch();
    }

    protected Version() {
        super();
    }

    public static final Version getInstance() {
        return SINGLETON;
    }

    public void setNumbers(Numbers numbers) {
        this.numbers = numbers;
    }

    public void setBuildDate(String buildDate) {
        this.buildDate = buildDate;
    }
}
